# frozen_string_literal: true

# We keep a global variable with the site in it because we can't access
# it from the cleanup hook.
$site = nil

# Only run on the default locale since it's going to be in the root
# destination
Jekyll::Hooks.register :site, :post_render do |site|
  next unless site.locales?
  next unless site.default_locale?

  $site = site
end

# Keep files in other locales since they're not generated by the default
# locale.
Jekyll::Hooks.register :clean, :on_obsolete do |obsolete|
  next if $site.nil?

  $site.locales.each do |locale|
    next if locale == $site.locale

    obsolete.delete_if do |x|
      x.sub($site.dest + '/', '').start_with? locale
    end
  end
end
